Other Resources
===============

**Scikit-learn astronomy tutorial:** `<http://astroML.github.com/sklearn_tutorial>`_
    This is an online tutorial which introduces the scikit-learn interface and
    the fundamental ideas of machine learning, and applies them within the
    context of astronomical data analysis.  It includes several videos of the
    tutorial being presented at conferences.

**Scikit-learn documentation:** `<http://scikit-learn.org>`_
    The scikit-learn documentation is extensive, and features detailed
    information on many of the routines used in the astroML examples.

**Matplotlib documentation:** `<http://matplotlib.org>`_
    Matplotlib enables all the plots on this website, and its website includes
    extensive documentation and examples.  See especially the example gallery.
    
**IPython documentation:** `<http://ipython.org>`_
    IPython is is an enhanced interactive python interpreter, and also
    provides a framework for parallel computing and cross-platform sharing
    of code and results.  It is an essential tool for any scientific
    python user.

**Python scientific lecture notes:** `<http://scipy-lectures.github.com/>`_
    These notes cover some of the basics of scientific python, including
    numpy, scipy, and matplotlib.  From there they move into an in-depth
    exploration of more advanced and specialized topics in scientific
    computing.
